"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = LinearShadowCanvas;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeSkia = require("@shopify/react-native-skia");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * LinearShadowCanvas
 * -------------------
 * A Skia-based component that renders a RoundedRect with a
 * linear gradient fill. It also applies an inner shadow
 * and (optionally) a reflected light effect.
 */
function LinearShadowCanvas({
  width,
  height,
  style,
  shadowColor,
  shadowOffset,
  shadowBlur,
  inset,
  reflectedLightColor,
  reflectedLightOffset,
  reflectedLightBlur,
  from = 'top',
  to = 'bottom',
  colors = ['#FFFFFF', '#FFFFFF'],
  ...props
}) {
  const isReflectedLightEnabled = props.isReflectedLightEnabled !== undefined ? props.isReflectedLightEnabled : inset;
  const boxRadius = Number(style['borderRadius']) || 0;
  const top = (0, _reactNativeSkia.vec)(width / 2, 0);
  const bottom = (0, _reactNativeSkia.vec)(width / 2, height);
  const left = (0, _reactNativeSkia.vec)(0, height / 2);
  const right = (0, _reactNativeSkia.vec)(width, height / 2);
  const direction = {
    top,
    bottom,
    left,
    right
  };
  const outerShadowOffset = (0, _react.useMemo)(() => {
    if (!inset) {
      return {
        shadowColor: inset ? 'transparent' : shadowColor,
        shadowOffset,
        // blur: 0 ~ 20, opacity: 0 ~ 1
        shadowOpacity: shadowBlur / 20
      };
    }
    return null;
  }, [inset, shadowColor, shadowBlur]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
    style: [outerShadowOffset, style, {
      position: 'absolute',
      left: 0,
      top: 0,
      backgroundColor: 'transparent',
      width,
      height
    }],
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.RoundedRect, {
      x: 0,
      y: 0,
      width: width,
      height: height,
      r: boxRadius,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.LinearGradient, {
        start: direction[from],
        end: direction[to],
        colors: colors
      }), inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: shadowOffset.width,
        dy: shadowOffset.height,
        blur: shadowBlur,
        color: shadowColor,
        inner: true
      }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: reflectedLightOffset.width,
        dy: reflectedLightOffset.height,
        blur: reflectedLightBlur,
        color: reflectedLightColor,
        inner: true
      })]
    })
  });
}
//# sourceMappingURL=LinearShadowCanvas.js.map