"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = ShadowCanvas;
var _react = _interopRequireWildcard(require("react"));
var _reactNativeSkia = require("@shopify/react-native-skia");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * ShadowCanvas
 * -------------
 * Responsible for rendering the inset (or regular) shadow effect
 * inside a Skia <Canvas>. This includes the main shadow layer and
 * an optional reflected light layer. Typically used in conjunction
 * with a parent container like `ShadowView`.
 */
function ShadowCanvas({
  width,
  height,
  style,
  shadowColor,
  shadowOffset,
  shadowBlur,
  backgroundColor,
  inset,
  reflectedLightColor,
  reflectedLightOffset,
  reflectedLightBlur,
  ...props
}) {
  /**
   * Determine if the reflected light layer should be rendered.
   * If `isReflectedLightEnabled` is explicitly set, use that.
   * Otherwise, default to rendering reflected light if `inset` is true.
   */
  const isReflectedLightEnabled = props.isReflectedLightEnabled !== undefined ? props.isReflectedLightEnabled : inset;

  /**
   * Extract a uniform corner radius from `style.borderRadius`.
   * If no radius is provided, default to 0 for sharp corners.
   * Note: more advanced logic may be needed to handle differing
   * corner radii on each corner.
   */
  const boxRadius = Number(style['borderRadius']) || 0;

  // Prepare the shadow offset and blur for the main shadow layer.
  // You can overwrite these values with `style` property.
  const outerShadowOffset = (0, _react.useMemo)(() => {
    if (!inset) {
      return {
        shadowColor: inset ? 'transparent' : shadowColor,
        shadowOffset,
        // blur: 0 ~ 20, opacity: 0 ~ 1
        shadowOpacity: shadowBlur / 20
      };
    }
    return null;
  }, [inset, shadowColor, shadowBlur]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Canvas, {
    style: [outerShadowOffset, style, {
      position: 'absolute',
      left: 0,
      top: 0,
      backgroundColor: 'transparent',
      width,
      height
    }],
    children: /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNativeSkia.RoundedRect, {
      x: 0,
      y: 0,
      width: width,
      height: height,
      r: boxRadius,
      color: backgroundColor // The background fill of the rect
      ,
      children: [inset && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: shadowOffset.width,
        dy: shadowOffset.height,
        blur: shadowBlur,
        color: shadowColor,
        inner: true
      }), isReflectedLightEnabled && /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNativeSkia.Shadow, {
        dx: reflectedLightOffset.width,
        dy: reflectedLightOffset.height,
        blur: reflectedLightBlur,
        color: reflectedLightColor,
        inner: true
      })]
    })
  });
}
//# sourceMappingURL=ShadowCanvas.js.map