"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ShadowView = exports.LinearShadowView = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _ShadowCanvas = _interopRequireDefault(require("./ShadowCanvas.js"));
var _utils = require("../utils.js");
var _LinearShadowCanvas = _interopRequireDefault(require("./LinearShadowCanvas.js"));
var _jsxRuntime = require("react/jsx-runtime");
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
const _ShadowView = ({
  ...props
}) => {
  const [boxSize, setBoxSize] = _react.default.useState({
    width: 0,
    height: 0
  });

  // Determine the final background color (pulling from `props.style` or a default).
  const backgroundColor = (0, _utils.getBackgroundColor)(props);

  // Compute final shadow and reflected-light properties from the provided props.
  const shadowProperties = (0, _utils.getShadowProperty)(props);
  const isLinear = (0, _react.useMemo)(() => {
    return !!props.colors[0];
  }, [props.colors]);
  return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.Pressable
  /**
   * onLayout captures the size of this component once it’s rendered.
   * We store these dimensions in state so we can pass them to the <Canvas>.
   */, {
    onLayout: ({
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    }) => setBoxSize({
      width,
      height
    }),
    ...props,
    style: [props.style, {
      backgroundColor: 'transparent'
    }],
    children: [boxSize.width === 0 && boxSize.height === 0 ? null : isLinear ? /*#__PURE__*/(0, _jsxRuntime.jsx)(_LinearShadowCanvas.default, {
      ...props,
      ...shadowProperties,
      backgroundColor: backgroundColor,
      width: boxSize.width,
      height: boxSize.height
    }) : /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowCanvas.default, {
      ...props,
      ...shadowProperties,
      backgroundColor: backgroundColor,
      width: boxSize.width,
      height: boxSize.height
    }), props.children]
  });
};

/**
 * ShadowView
 * -----------
 * A React Native component that renders an inset (or standard) shadow around its children
 * using a Skia-based <Canvas>. The shadow parameters (color, blur, offsets) and background
 * color can be customized via props.
 */
const ShadowView = ({
  ...props
}) => {
  const colors = [null];
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowView, {
    ...props,
    colors: colors
  });
};

/**
 * LinearShadowView
 * -----------------
 * A specialized component for rendering a view with a
 * linear gradient background and an optional inset shadow.
 * It measures the component's size, then delegates
 * the actual drawing to `LinearShadowCanvas`.
 */
exports.ShadowView = ShadowView;
const LinearShadowView = ({
  ...props
}) => {
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_ShadowView, {
    ...props
  });
};
exports.LinearShadowView = LinearShadowView;
//# sourceMappingURL=ShadowView.js.map