"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DEFAULT_SHADOW_OFFSET_SCALE = exports.DEFAULT_SHADOW_COLOR = exports.DEFAULT_SHADOW_BLUR = exports.DEFAULT_REFLECTED_LIGHT_OFFSET_SCALE = exports.DEFAULT_REFLECTED_LIGHT_COLOR = exports.DEFAULT_REFLECTED_LIGHT_BLUR = exports.DEFAULT_BACKGROUND_COLOR = void 0;
// These two scales are opposite each other to create a "reflected light" effect.
const DEFAULT_SHADOW_OFFSET_SCALE = exports.DEFAULT_SHADOW_OFFSET_SCALE = 2;
const DEFAULT_REFLECTED_LIGHT_OFFSET_SCALE = exports.DEFAULT_REFLECTED_LIGHT_OFFSET_SCALE = 2;

/**
 * Default values used when a particular prop isn't provided:
 *   - DEFAULT_BACKGROUND_COLOR: typical white background
 *   - DEFAULT_REFLECTED_LIGHT_COLOR: a semi-transparent white for "reflected light" effect
 *   - DEFAULT_SHADOW_COLOR: a dark, semi-transparent color for shadows
 */
const DEFAULT_BACKGROUND_COLOR = exports.DEFAULT_BACKGROUND_COLOR = '#FFFFFF';
const DEFAULT_REFLECTED_LIGHT_COLOR = exports.DEFAULT_REFLECTED_LIGHT_COLOR = '#EEE9E92D';
const DEFAULT_SHADOW_COLOR = exports.DEFAULT_SHADOW_COLOR = '#2F2F2FBC';

/**
 * Default shadow blur radius for the main shadow and reflected light.
 * These values control how soft or diffuse the shadow/highlight appears.
 * Higher values create larger, softer shadows.
 * */
const DEFAULT_SHADOW_BLUR = exports.DEFAULT_SHADOW_BLUR = 3;
const DEFAULT_REFLECTED_LIGHT_BLUR = exports.DEFAULT_REFLECTED_LIGHT_BLUR = 3;

/**
 * InnerShadowProps defines the basic requirements for
 * an inset-shadow component. These props control:
 *   - Basic layout (width, height, backgroundColor)
 *   - Shadow styling (color, blur, offset)
 *   - Optional reflected light styling (color, blur, offset)
 *   - PressableProps allows the shadowed element to be interactable.
 */

/**
 * LINEAR_DIRECTION defines the four basic directions for
 * linear gradients. Additional or diagonal directions can be
 * implemented if needed (e.g., 'topLeft', 'bottomRight', etc.).
 */

/**
 * LinearInnerShadowViewProps extends InnerShadowProps
 * to incorporate linear gradient capabilities.
 *
 * @param from - The start direction of the linear gradient (e.g., 'top')
 * @param to - The end direction of the linear gradient (e.g., 'bottom')
 * @param colors - An array of colors for the gradient. Using multiple colors
 *                 creates more visually interesting transitions.
 */
//# sourceMappingURL=types.js.map