"use strict";

import React, { useMemo } from 'react';
import { Pressable } from 'react-native';
import ShadowCanvas from "./ShadowCanvas.js";
import { getBackgroundColor, getShadowProperty } from "../utils.js";
import LinearShadowCanvas from "./LinearShadowCanvas.js";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const _ShadowView = ({
  ...props
}) => {
  const [boxSize, setBoxSize] = React.useState({
    width: 0,
    height: 0
  });

  // Determine the final background color (pulling from `props.style` or a default).
  const backgroundColor = getBackgroundColor(props);

  // Compute final shadow and reflected-light properties from the provided props.
  const shadowProperties = getShadowProperty(props);
  const isLinear = useMemo(() => {
    return !!props.colors[0];
  }, [props.colors]);
  return /*#__PURE__*/_jsxs(Pressable
  /**
   * onLayout captures the size of this component once it’s rendered.
   * We store these dimensions in state so we can pass them to the <Canvas>.
   */, {
    onLayout: ({
      nativeEvent: {
        layout: {
          width,
          height
        }
      }
    }) => setBoxSize({
      width,
      height
    }),
    ...props,
    style: [props.style, {
      backgroundColor: 'transparent'
    }],
    children: [boxSize.width === 0 && boxSize.height === 0 ? null : isLinear ? /*#__PURE__*/_jsx(LinearShadowCanvas, {
      ...props,
      ...shadowProperties,
      backgroundColor: backgroundColor,
      width: boxSize.width,
      height: boxSize.height
    }) : /*#__PURE__*/_jsx(ShadowCanvas, {
      ...props,
      ...shadowProperties,
      backgroundColor: backgroundColor,
      width: boxSize.width,
      height: boxSize.height
    }), props.children]
  });
};

/**
 * ShadowView
 * -----------
 * A React Native component that renders an inset (or standard) shadow around its children
 * using a Skia-based <Canvas>. The shadow parameters (color, blur, offsets) and background
 * color can be customized via props.
 */
const ShadowView = ({
  ...props
}) => {
  const colors = [null];
  return /*#__PURE__*/_jsx(_ShadowView, {
    ...props,
    colors: colors
  });
};

/**
 * LinearShadowView
 * -----------------
 * A specialized component for rendering a view with a
 * linear gradient background and an optional inset shadow.
 * It measures the component's size, then delegates
 * the actual drawing to `LinearShadowCanvas`.
 */
const LinearShadowView = ({
  ...props
}) => {
  return /*#__PURE__*/_jsx(_ShadowView, {
    ...props
  });
};
export { ShadowView, LinearShadowView };
//# sourceMappingURL=ShadowView.js.map