import { InnerShadowProps } from './types';
/**
 * getBackgroundColor retrieves the final background color
 * from either:
 *   1) props.backgroundColor
 *   2) style.backgroundColor
 *   3) DEFAULT_BACKGROUND_COLOR
 *
 * This ensures there is always a valid color for the component’s background.
 */
export declare function getBackgroundColor(props: Pick<InnerShadowProps, 'backgroundColor' | 'style' | 'children'>): string;
/**
 * getShadowProperty determines the final configuration for both
 * the main shadow and any reflected light. It merges default values
 * with provided props to form a complete “shadow settings” object.
 *
 * - shadowOffset / reflectedLightOffset: how far the shadows/highlights
 *   are shifted in x and y.
 * - shadowColor / reflectedLightColor: colors used for each effect.
 * - shadowBlur / reflectedLightBlur: blur radius for the softness/spread
 *   of the shadow or highlight.
 *
 * @param props - The props object containing shadow-related settings.
 * @returns {
 * shadowOffset, reflectedLightOffset, shadowColor, reflectedLightColor, shadowBlur, reflectedLightBlur}
 */
export declare function getShadowProperty(props: Omit<InnerShadowProps, 'children'>): {
    shadowOffset: {
        width: number;
        height: number;
    };
    reflectedLightOffset: {
        width: number;
        height: number;
    };
    shadowColor: string;
    reflectedLightColor: string;
    shadowBlur: number;
    reflectedLightBlur: number;
};
//# sourceMappingURL=utils.d.ts.map